@@ -4,6 +4,8 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
+#include "testhelper.h"
+
 #include <applicationcontroller.h>
 #include <pkpassmanager.h>
 #include <reservationmanager.h>
@@ -13,6 +15,7 @@
 #include <transfermanager.h>
 #include <tripgroupmanager.h>
 
+#include <KItinerary/ExtractorCapabilities>
 #include <KItinerary/File>
 
 #include <QUrl>
@@ -25,29 +28,6 @@ class AppControllerTest : public QObject
 {
     Q_OBJECT
 private:
-    void clearPasses(PkPassManager *mgr)
-    {
-        for (const auto &id : mgr->passes()) {
-            mgr->removePass(id);
-        }
-    }
-
-    void clearReservations(ReservationManager *mgr)
-    {
-        const auto batches = mgr->batches(); // copy, as this is getting modified in the process
-        for (const auto &id : batches) {
-            mgr->removeBatch(id);
-        }
-        QCOMPARE(mgr->batches().size(), 0);
-    }
-
-    void clearDocuments(DocumentManager *mgr)
-    {
-        for (const auto &id : mgr->documents()) {
-            mgr->removeDocument(id);
-        }
-    }
-
     QByteArray readFile(const QString &fn)
     {
         QFile f(fn);
@@ -55,6 +35,11 @@ private:
         return f.readAll();
     }
 
+    bool hasZxing()
+    {
+        return KItinerary::ExtractorCapabilities::capabilitiesString().contains(QLatin1String("zxing"), Qt::CaseInsensitive);
+    }
+
 private Q_SLOTS:
     void initTestCase()
     {
@@ -65,66 +50,101 @@ private Q_SLOTS:
     void testImportData()
     {
         PkPassManager passMgr;
-        clearPasses(&passMgr);
+        Test::clearAll(&passMgr);
         QSignalSpy passSpy(&passMgr, &PkPassManager::passAdded);
         QVERIFY(passSpy.isValid());
 
         ReservationManager resMgr;
-        clearReservations(&resMgr);
+        Test::clearAll(&resMgr);
         QSignalSpy resSpy(&resMgr, &ReservationManager::reservationAdded);
         QVERIFY(resSpy.isValid());
 
+        DocumentManager docMgr;
+        Test::clearAll(&docMgr);
+
+        HealthCertificateManager healthCertMgr;
+
         ApplicationController appController;
+        QSignalSpy infoSpy(&appController, &ApplicationController::infoMessage);
         appController.setPkPassManager(&passMgr);
         appController.setReservationManager(&resMgr);
+        appController.setDocumentManager(&docMgr);
+        appController.setHealthCertificateManager(&healthCertMgr);
 
         appController.importData(readFile(QLatin1String(SOURCE_DIR "/data/4U8465-v1.json")));
         QCOMPARE(resSpy.size(), 1);
         QCOMPARE(passSpy.size(), 0);
+        QCOMPARE(infoSpy.size(), 1);
         appController.importData(readFile(QLatin1String(SOURCE_DIR "/data/boardingpass-v1.pkpass")));
-        QCOMPARE(resSpy.size(), 1);
-        QCOMPARE(passSpy.size(), 1);
-        appController.importData("M1DOE/JOHN            EXXX007 TXLBRUSN 2592 110Y");
         QCOMPARE(resSpy.size(), 2);
         QCOMPARE(passSpy.size(), 1);
-        // TODO PDF
+        QCOMPARE(infoSpy.size(), 2);
+        appController.importData("M1DOE/JOHN            EXXX007 TXLBRUSN 2592 110Y");
+        QCOMPARE(resSpy.size(), 3);
+        QCOMPARE(passSpy.size(), 1);
+        QCOMPARE(infoSpy.size(), 3);
+        appController.importData(readFile(QLatin1String(SOURCE_DIR "/data/iata-bcbp-demo.pdf")));
+        if (!hasZxing()) {
+            QSKIP("Built without ZXing");
+        }
+        QCOMPARE(resSpy.size(), 4);
+        QCOMPARE(passSpy.size(), 1);
+        QCOMPARE(infoSpy.size(), 4);
+        QCOMPARE(docMgr.documents().size(), 1);
     }
 
     void testImportFile()
     {
         PkPassManager passMgr;
-        clearPasses(&passMgr);
+        Test::clearAll(&passMgr);
         QSignalSpy passSpy(&passMgr, &PkPassManager::passAdded);
         QVERIFY(passSpy.isValid());
 
         ReservationManager resMgr;
-        clearReservations(&resMgr);
+        Test::clearAll(&resMgr);
         QSignalSpy resSpy(&resMgr, &ReservationManager::reservationAdded);
         QVERIFY(resSpy.isValid());
 
+        DocumentManager docMgr;
+        Test::clearAll(&docMgr);
+
+        HealthCertificateManager healthCertMgr;
+
         ApplicationController appController;
+        QSignalSpy infoSpy(&appController, &ApplicationController::infoMessage);
         appController.setPkPassManager(&passMgr);
         appController.setReservationManager(&resMgr);
+        appController.setDocumentManager(&docMgr);
+        appController.setHealthCertificateManager(&healthCertMgr);
 
         appController.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/4U8465-v1.json")));
         QCOMPARE(resSpy.size(), 1);
         QCOMPARE(passSpy.size(), 0);
+        QCOMPARE(infoSpy.size(), 1);
         appController.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/boardingpass-v1.pkpass")));
-        QCOMPARE(resSpy.size(), 1);
+        QCOMPARE(resSpy.size(), 2);
         QCOMPARE(passSpy.size(), 1);
-        // TODO PDF
+        QCOMPARE(infoSpy.size(), 2);
+        appController.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/iata-bcbp-demo.pdf")));
+        if (!hasZxing()) {
+            QSKIP("Built without ZXing");
+        }
+        QCOMPARE(resSpy.size(), 3);
+        QCOMPARE(passSpy.size(), 1);
+        QCOMPARE(infoSpy.size(), 3);
+        QCOMPARE(docMgr.documents().size(), 1);
     }
 
     void testExportFile()
     {
         PkPassManager passMgr;
-        clearPasses(&passMgr);
+        Test::clearAll(&passMgr);
 
         ReservationManager resMgr;
-        clearReservations(&resMgr);
+        Test::clearAll(&resMgr);
 
         DocumentManager docMgr;
-        clearDocuments(&docMgr);
+        Test::clearAll(&docMgr);
 
         TripGroupManager tripGroupMgr;
         tripGroupMgr.setReservationManager(&resMgr);
@@ -137,6 +157,7 @@ private Q_SLOTS:
         HealthCertificateManager healthCertMgr;
 
         ApplicationController appController;
+        QSignalSpy infoSpy(&appController, &ApplicationController::infoMessage);
         appController.setPkPassManager(&passMgr);
         appController.setReservationManager(&resMgr);
         appController.setDocumentManager(&docMgr);
@@ -146,39 +167,43 @@ private Q_SLOTS:
 
         appController.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/4U8465-v1.json")));
         appController.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/boardingpass-v1.pkpass")));
-        QCOMPARE(resMgr.batches().size(), 1);
+        QCOMPARE(resMgr.batches().size(), 2);
         QCOMPARE(passMgr.passes().size(), 1);
+        QCOMPARE(infoSpy.size(), 2);
 
         QTemporaryFile tmp;
         QVERIFY(tmp.open());
         tmp.close();
-        appController.exportToFile(tmp.fileName());
+        appController.exportToFile(QUrl::fromLocalFile(tmp.fileName()));
+        QCOMPARE(infoSpy.size(), 3);
 
         KItinerary::File f(tmp.fileName());
         QVERIFY(f.open(KItinerary::File::Read));
-        QCOMPARE(f.reservations().size(), 1);
+        QCOMPARE(f.reservations().size(), 2);
         QCOMPARE(f.passes().size(), 1);
 
-        clearPasses(&passMgr);
-        clearReservations(&resMgr);
-        clearDocuments(&docMgr);
+        Test::clearAll(&passMgr);
+        Test::clearAll(&resMgr);
+        Test::clearAll(&docMgr);
         QCOMPARE(resMgr.batches().size(), 0);
         QCOMPARE(passMgr.passes().size(), 0);
 
         appController.importFromUrl(QUrl::fromLocalFile(tmp.fileName()));
-        QCOMPARE(resMgr.batches().size(), 1);
+        QCOMPARE(resMgr.batches().size(), 2);
         QCOMPARE(passMgr.passes().size(), 1);
+        QCOMPARE(infoSpy.size(), 4);
 
-        clearPasses(&passMgr);
-        clearReservations(&resMgr);
+        Test::clearAll(&passMgr);
+        Test::clearAll(&resMgr);
         QCOMPARE(resMgr.batches().size(), 0);
         QCOMPARE(passMgr.passes().size(), 0);
 
         QFile bundle(tmp.fileName());
         QVERIFY(bundle.open(QFile::ReadOnly));
         appController.importData(bundle.readAll());
-        QCOMPARE(resMgr.batches().size(), 1);
+        QCOMPARE(resMgr.batches().size(), 2);
         QCOMPARE(passMgr.passes().size(), 1);
+        QCOMPARE(infoSpy.size(), 5);
     }
 };
 
